
import { useState } from 'react';
import { ArrowLeft, Download, Database, Activity, Loader2 } from 'lucide-react';
import { useNavigate } from 'react-router-dom';
import { toast } from "sonner";
import Navbar from '@/components/Navbar';
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { downloadDatasetCSV, downloadSimulatedModel } from '@/lib/dataSimulation';

const DatasetModel = () => {
  const navigate = useNavigate();
  const [isGeneratingDataset, setIsGeneratingDataset] = useState(false);
  const [isGeneratingModel, setIsGeneratingModel] = useState(false);
  
  const handleDatasetDownload = (size: number) => {
    setIsGeneratingDataset(true);
    
    // Use setTimeout to show the loading state (not necessary but provides better UX)
    setTimeout(() => {
      try {
        downloadDatasetCSV(size);
        toast.success(`Dataset with ${size} records generated and downloaded successfully`);
      } catch (error) {
        console.error("Error generating dataset:", error);
        toast.error("Error generating dataset", {
          description: "There was an error generating the dataset. Please try again.",
        });
      } finally {
        setIsGeneratingDataset(false);
      }
    }, 1000);
  };
  
  const handleModelDownload = () => {
    setIsGeneratingModel(true);
    
    // Use setTimeout to show the loading state
    setTimeout(() => {
      try {
        downloadSimulatedModel();
        toast.success("Model artifact generated and downloaded successfully");
      } catch (error) {
        console.error("Error generating model:", error);
        toast.error("Error generating model", {
          description: "There was an error generating the model artifact. Please try again.",
        });
      } finally {
        setIsGeneratingModel(false);
      }
    }, 1500);
  };

  return (
    <div className="min-h-screen bg-gradient-to-b from-white to-gray-50">
      <Navbar />
      
      <main className="pt-32 pb-16">
        <div className="container max-w-4xl mx-auto px-4">
          <button 
            onClick={() => navigate(-1)}
            className="flex items-center gap-1 text-muted-foreground hover:text-foreground transition-colors mb-8"
          >
            <ArrowLeft size={16} />
            <span>Back</span>
          </button>
          
          <div className="mb-8 animate-fade-up">
            <h1 className="heading-lg mb-2">Credit Default Dataset & Model</h1>
            <p className="text-lg text-muted-foreground">
              Generate and download simulated credit default data and model artifacts for training and integration purposes.
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
            <Card className="animate-fade-up">
              <CardHeader>
                <CardTitle className="flex items-center gap-2">
                  <Database className="h-5 w-5 text-brand-blue" />
                  <span>Simulated Dataset</span>
                </CardTitle>
                <CardDescription>
                  Download labeled historical data of borrowers with default status
                </CardDescription>
              </CardHeader>
              <CardContent>
                <p className="text-sm mb-4">
                  This dataset includes personal information, financial data, geographic data, 
                  payment history for the last 12 months, and default status (target variable).
                </p>
                <div className="space-y-2 text-sm text-muted-foreground">
                  <div><strong>Features:</strong> Age, Gender, Marital Status, Education, Home Ownership, Income, Spending, etc.</div>
                  <div><strong>Target:</strong> Whether the client defaulted (1) or not (0)</div>
                  <div><strong>Format:</strong> CSV file with header row</div>
                </div>
              </CardContent>
              <CardFooter className="flex flex-wrap gap-2 justify-between">
                <Button
                  onClick={() => handleDatasetDownload(500)}
                  disabled={isGeneratingDataset}
                  variant="outline"
                  size="sm"
                  className="flex-1"
                >
                  {isGeneratingDataset ? (
                    <>
                      <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                      Generating...
                    </>
                  ) : (
                    <>
                      <Download className="mr-2 h-4 w-4" />
                      500 Records
                    </>
                  )}
                </Button>
                <Button
                  onClick={() => handleDatasetDownload(1000)}
                  disabled={isGeneratingDataset}
                  variant="outline"
                  size="sm"
                  className="flex-1"
                >
                  {isGeneratingDataset ? (
                    <>
                      <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                      Generating...
                    </>
                  ) : (
                    <>
                      <Download className="mr-2 h-4 w-4" />
                      1,000 Records
                    </>
                  )}
                </Button>
                <Button
                  onClick={() => handleDatasetDownload(5000)}
                  disabled={isGeneratingDataset}
                  variant="default"
                  size="sm"
                  className="flex-1"
                >
                  {isGeneratingDataset ? (
                    <>
                      <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                      Generating...
                    </>
                  ) : (
                    <>
                      <Download className="mr-2 h-4 w-4" />
                      5,000 Records
                    </>
                  )}
                </Button>
              </CardFooter>
            </Card>

            <Card className="animate-fade-up" style={{ animationDelay: '0.1s' }}>
              <CardHeader>
                <CardTitle className="flex items-center gap-2">
                  <Activity className="h-5 w-5 text-brand-blue" />
                  <span>Model Artifact</span>
                </CardTitle>
                <CardDescription>
                  Download a simulated Random Forest model for credit default prediction
                </CardDescription>
              </CardHeader>
              <CardContent>
                <p className="text-sm mb-4">
                  This is a simulated model artifact that represents a trained Random Forest 
                  model for credit default prediction, including feature importances and model metrics.
                </p>
                <div className="space-y-2 text-sm text-muted-foreground">
                  <div><strong>Model Type:</strong> Random Forest Classifier</div>
                  <div><strong>Performance:</strong> ~87% accuracy, 0.89 AUC-ROC</div>
                  <div><strong>Format:</strong> JSON file with model parameters and metadata</div>
                </div>
              </CardContent>
              <CardFooter>
                <Button
                  onClick={handleModelDownload}
                  disabled={isGeneratingModel}
                  className="w-full"
                >
                  {isGeneratingModel ? (
                    <>
                      <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                      Generating Model...
                    </>
                  ) : (
                    <>
                      <Download className="mr-2 h-4 w-4" />
                      Download Model Artifact
                    </>
                  )}
                </Button>
              </CardFooter>
            </Card>
          </div>
          
          <div className="mt-8 p-6 bg-muted rounded-lg animate-fade-up" style={{ animationDelay: '0.2s' }}>
            <h3 className="text-lg font-semibold mb-2">How to Use These Resources</h3>
            <div className="space-y-4 text-sm">
              <p>
                <strong>1. Download the Dataset:</strong> The CSV file contains simulated client data with features
                that correlate with default risk. You can use this data to train your own machine learning models.
              </p>
              <p>
                <strong>2. Download the Model:</strong> The JSON file represents a simulated pre-trained model
                that you can use as a reference for feature importance and expected performance metrics.
              </p>
              <p>
                <strong>3. Integration:</strong> This application already uses similar model logic for credit
                risk prediction. The downloadable resources allow you to analyze the data and model structure
                for your own implementations.
              </p>
            </div>
          </div>
        </div>
      </main>
    </div>
  );
};

export default DatasetModel;
